@@ -1,13 +1,7 @@
 from typing import TypeVar, Union
 
 from imm import MuteState, NormalState, Path, Results, State, Step
-from nmm import (
-    AminoAlphabet,
-    CanonicalAminoAlphabet,
-    CodonState,
-    DNAAlphabet,
-    RNAAlphabet,
-)
+from nmm import AminoAlphabet, CodonState, DNAAlphabet, IUPACAminoAlphabet, RNAAlphabet
 
 from .fragment import Fragment
 
@@ -25,7 +19,7 @@ MutableStep = Step[Union[TState, MuteState]]
 MutablePath = Path[Step[Union[TState, MuteState]]]
 MutableResults = Results[Union[TState, MuteState]]
 
-HMMERAlphabet = Union[RNAAlphabet, DNAAlphabet, CanonicalAminoAlphabet]
+HMMERAlphabet = Union[RNAAlphabet, DNAAlphabet, IUPACAminoAlphabet]
 
 
 __all__ = [
